orcid\_api\.apis package
========================

Submodules
----------

orcid\_api\.apis\.development\_member\_apiv30\_dev1\_api module
---------------------------------------------------------------

.. automodule:: orcid_api.apis.development_member_apiv30_dev1_api
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.apis\.member\_apiv20\_api module
--------------------------------------------

.. automodule:: orcid_api.apis.member_apiv20_api
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.apis\.member\_apiv21\_api module
--------------------------------------------

.. automodule:: orcid_api.apis.member_apiv21_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: orcid_api.apis
    :members:
    :undoc-members:
    :show-inheritance:
